Documentation
¶
Index ¶
- type Buffer
- func (b *Buffer) Close() error
- func (b *Buffer) Iterate(f func(p []byte) (int, bool, error)) (int64, error)
- func (b *Buffer) Read(p []byte) (int, error)
- func (b *Buffer) ReadByte() (byte, error)
- func (b *Buffer) ReadFrom(r io.Reader) (int64, error)
- func (b *Buffer) Write(p []byte) (int, error)
- func (b *Buffer) WriteByte(v byte) error
- func (b *Buffer) WriteTo(w io.Writer) (int64, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Buffer ¶
type Buffer struct {
// contains filtered or unexported fields
}
Buffer is the ring buffer implementation.
func (*Buffer) Iterate ¶
Iterate implements iterator over available data. It makes all the available data to the iterator, then it should say how many bytes has been used and if iterator is interested in receiving more data.
Click to show internal directories.
Click to hide internal directories.